@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-runtime service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/literals/)
 
 Usage::
 
@@ -19,7 +19,7 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("SageMakerRuntimeServiceName", "ServiceName", "ResourceServiceName")
+__all__ = ("SageMakerRuntimeServiceName", "ServiceName", "ResourceServiceName", "RegionName")
 
 
 SageMakerRuntimeServiceName = Literal["sagemaker-runtime"]
@@ -141,6 +141,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -338,3 +339,26 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
