@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-runtime service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/type_defs/)
 
 Usage::
 
@@ -31,18 +31,31 @@ __all__ = (
     "ResponseMetadataTypeDef",
 )
 
-InvokeEndpointAsyncInputRequestTypeDef = TypedDict(
-    "InvokeEndpointAsyncInputRequestTypeDef",
+_RequiredInvokeEndpointAsyncInputRequestTypeDef = TypedDict(
+    "_RequiredInvokeEndpointAsyncInputRequestTypeDef",
     {
         "EndpointName": str,
         "InputLocation": str,
-        "ContentType": NotRequired[str],
-        "Accept": NotRequired[str],
-        "CustomAttributes": NotRequired[str],
-        "InferenceId": NotRequired[str],
-        "RequestTTLSeconds": NotRequired[int],
     },
 )
+_OptionalInvokeEndpointAsyncInputRequestTypeDef = TypedDict(
+    "_OptionalInvokeEndpointAsyncInputRequestTypeDef",
+    {
+        "ContentType": str,
+        "Accept": str,
+        "CustomAttributes": str,
+        "InferenceId": str,
+        "RequestTTLSeconds": int,
+    },
+    total=False,
+)
+
+
+class InvokeEndpointAsyncInputRequestTypeDef(
+    _RequiredInvokeEndpointAsyncInputRequestTypeDef, _OptionalInvokeEndpointAsyncInputRequestTypeDef
+):
+    pass
+
 
 InvokeEndpointAsyncOutputTypeDef = TypedDict(
     "InvokeEndpointAsyncOutputTypeDef",
@@ -53,20 +66,33 @@ InvokeEndpointAsyncOutputTypeDef = TypedDict(
     },
 )
 
-InvokeEndpointInputRequestTypeDef = TypedDict(
-    "InvokeEndpointInputRequestTypeDef",
+_RequiredInvokeEndpointInputRequestTypeDef = TypedDict(
+    "_RequiredInvokeEndpointInputRequestTypeDef",
     {
         "EndpointName": str,
         "Body": Union[bytes, IO[bytes], StreamingBody],
-        "ContentType": NotRequired[str],
-        "Accept": NotRequired[str],
-        "CustomAttributes": NotRequired[str],
-        "TargetModel": NotRequired[str],
-        "TargetVariant": NotRequired[str],
-        "TargetContainerHostname": NotRequired[str],
-        "InferenceId": NotRequired[str],
     },
 )
+_OptionalInvokeEndpointInputRequestTypeDef = TypedDict(
+    "_OptionalInvokeEndpointInputRequestTypeDef",
+    {
+        "ContentType": str,
+        "Accept": str,
+        "CustomAttributes": str,
+        "TargetModel": str,
+        "TargetVariant": str,
+        "TargetContainerHostname": str,
+        "InferenceId": str,
+    },
+    total=False,
+)
+
+
+class InvokeEndpointInputRequestTypeDef(
+    _RequiredInvokeEndpointInputRequestTypeDef, _OptionalInvokeEndpointInputRequestTypeDef
+):
+    pass
+
 
 InvokeEndpointOutputTypeDef = TypedDict(
     "InvokeEndpointOutputTypeDef",
